<?php require_once( dirname(__FILE__) . "/hobfus/HObfus.inc.php" ); ?>
<!doctype html>

<html>

<head>

<meta charset="utf-8">
<meta name="viewport" content="width=device-width, initial-scale=1.0, maximum-scale=1.0, user-scalable=no"/>

<title>Simple Batch Script for HObfus</title>

<style>
*,
*::before,
*::after{
	box-sizing:border-box;
}
body{
	margin:0;
	padding:0;
}
main{
	position:relative;
	margin:0 auto;
	padding:20px;
	max-width:1000px;
	font-family:"Verdana";
	font-size:18px;
}
li{
	margin:5px 0;
}
.btn{
	display:inline-block;
	margin:15px;
	padding:10px 15px;
	font-size:20px;
	text-decoration:none;
	border:1px solid #888;
	border-radius:4px;
}
.btn:hover{
	background:#eef;
}
.info,
.error{
	margin:15px 0;
	padding:15px;
	border-radius:5px;
}
.info{
	color:#080;
	background:#efe;
	border:1px solid #484;
}
.error{
	color:#f00;
	background:#fee;
	border:1px solid #f88;
}
</style>

</head>

<body>

<main>

<h2>Simple Batch Script for HObfus</h2>

<?php $cmd = isset( $_GET["cmd"] ) ? $_GET["cmd"] : ""; ?>
<?php if($cmd!="run"):?>

<ul>
<li>This batch script will obfuscate HTML files in the <b>input</b> folder and save them in the <b>output</b> folder.</li>
<li>You’ll find sample files in the <b>input</b> folder. Feel free to add your own HTML files there to obfuscate. You can obfuscate hundreds of files in just seconds!</li>
<li>This script is purposely kept basic so you can easily understand and modify it as needed.</li>
<li>Click the <b>RUN</b> button below to start obfuscating files in the <b>input</b> folder.</li>
</ul>

<a class="btn" href="index.php?cmd=run">RUN &gt;</a>

<?php else:?>

<a class="btn" href="index.php">&lt; BACK</a>

<?php

function printInfo( $str ) {
	echo "<div class='info'>" . $str . "</div>\n";
}

function printError( $str ) {
	echo "<div class='error'>" . $str . "</div>\n";
}

function obfuscateFile( $str ) {
	$header = "<!-- Obfuscated at %date-time% by HObfus( http://www.phpkobo.com/hobfus ) -->";
	$dt = date("Y-m-d H:i:s");
	$header = str_replace("%date-time%",$dt,$header);

	$cfg=array(
		"prepend"=>$header,
		"return-output"=>1
	);

	HObfus_begin( $cfg );
	echo $str;
	return HObfus_end();
}

function obfuscateFilesInInputFolder() {

	// load configurations from "config.inc.php"
	$cfg = array();
	include( dirname(__FILE__) . "/config.inc.php" );

	// path to the input folder
	$path_input = $cfg["path-input"];

	// path to the output folder
	$path_output = $cfg["path-output"];

	// url to the input folder
	$url_input = $cfg["url-input"];

	// url to the output folder
	$url_output = $cfg["url-output"];

	// check if the input folder is readable
	if( !is_readable( $path_input ) ) {
		printError( "The <b>input</b> folder is not readable. Please correct the permissions." );
		return;
	}

	// check if the outout folder is writable
	if( !is_writable( $path_output ) ) {
		printError( "The <b>output</b> folder is not writable. Please correct the permissions." );
		return;
	}

	// collect files to be obfuscated
	$files = array();
	foreach( glob( $path_input . "*" ) as $path ) {
		$files[] = basename($path);
	}
	sort($files);

	// check if there is at least one file to be obfuscated
	if( count( $files ) == 0 ) {
		printError( "There are no files to be obfuscated in the <b>input</b> folder." );
		return;
	}

	// report how many files to be obfuscated
	printInfo( count( $files ) . " file" . ( count( $files )>1 ? "s" : "" ) .
		" found in the <b>input</b> folder!" );

	// obfuscate each file and save them in the output folder
	$idx=0;
	foreach( $files as $fn ) {
		$idx++;
		if( !is_readable( $path_input . $fn ) ) {
			printError( "[{$idx}] <b>{$fn}</b> is not readable in the <b>input</b> folder. Please correct the permissions." );
		} else if( file_exists( $path_output . $fn ) && !is_writable( $path_output . $fn ) ) {
			printError( "[{$idx}] <b>{$fn}</b> is not writable in the <b>output</b> folder. Please correct the permissions." );
		} else {
			printInfo( "[{$idx}] Obfuscating <b>" . $fn . "</b> ".
				"( ".
					"<a href='{$url_input}{$fn}' target='_blank'>input</a>, " .
					"<a href='{$url_output}{$fn}' target='_blank'>output</a> " .
				")" );
			file_put_contents( $path_output . $fn, obfuscateFile( file_get_contents( $path_input . $fn ) ) );
		}
	}

	// end of procedure
	printInfo( "DONE!" );

	// notice for free trial version users
	if(strpos($GLOBALS['__HOBFUS_PASSCODE__'],"FREE-TRIAL-VERSION")!==false){
		printInfo( "* The <b>hobfus</b> folder used in this script is a trial version. " .
			"Registered users can replace it with the licensed <b>hobfus</b> folder." );
	}
}

obfuscateFilesInInputFolder();

?>

<?php endif;?>

</main>

</body>

</html>
